crystal_toolkit.settings module — Crystal Toolkit documentation

# crystal_toolkit.settings module

class crystal_toolkit.settings.Settings(_env_file: Optional[Union[Path, str]] = '<object object>', _env_file_encoding: Optional[str] = None, _secrets_dir: Optional[Union[Path, str]] = None, *, DEBUG_MODE: bool = False, MP_EMBED_MODE: bool = False, TEST_MODE: bool = False, TRANSFORMATION_PREVIEWS: bool = False, REDIS_URL: str = 'redis://localhost:6379', ASSETS_PATH: str = '/Users/matt/git/crystal_toolkit/crystal_toolkit/apps/assets', PERSISTENCE: bool = True, PERSISTENCE_TYPE: Literal['memory', 'session', 'local'] = 'local')

  Bases: `BaseSettings`

  ASSETS_PATH: str
  class Config

    Bases: `object`

    env_prefix = 'CT_'
  DEBUG_MODE: bool
  MP_EMBED_MODE: bool
  PERSISTENCE: bool
  PERSISTENCE_TYPE: Literal['memory', 'session', 'local']
  REDIS_URL: str
  TEST_MODE: bool
  TRANSFORMATION_PREVIEWS: bool